This function locates the font file (and index) best matching a name and
optional style (italic/bold). A font file will be returned even if a match
isn't found, but it is not necessarily similar to the requested family and
it should not be relied on for font substitution. The aliases "sans",
"serif", and "mono" match to the system default sans-serif, serif, and
mono fonts respectively ("" is equivalent to "sans").